import time
from calendar import monthrange

from netforce.model import Model,fields,get_model
from netforce.access import get_active_company

class ReportLaborCost(Model):
    _name="clinic.report.labor.cost"
    _string="Report Labor Cost"
    _transient=True
    
    _fields={
        "date": fields.Date("Month"),
        "date_from": fields.Date("From", required=True),
        "date_to": fields.Date("To", required=True),
        "branch_id": fields.Many2One("clinic.branch","Branch"),
        "department_id": fields.Many2One("clinic.department","Department"),
    }

    def _get_date_from(self,context={}):
        year,month=time.strftime("%Y-%m").split("-")
        return '%s-%s-01'%(year,month)

    def _get_date_to(self,context={}):
        year,month,day=time.strftime("%Y-%m-%d").split("-")
        weekday, total_day=monthrange(int(year), int(month))
        return "%s-%s-%s"%(year,month,total_day)

    def default_get(self,field_names=None,context={},**kw):
        defaults=context.get("defaults",{})
        date_from=defaults.get("date_from", self._get_date_from())
        date_to=defaults.get("date_to", self._get_date_to())
        print('defaults ', defaults)
        res={
            'date': time.strftime("%Y-%m-%d"),
            'date_from': date_from,
            'date_to': date_to,
        }
        return res
    
    def get_report_data(self,ids,context={}):
        company_id=get_active_company()
        company=get_model("company").browse(company_id)
        defaults=self.default_get(context=context)
        date_from=defaults['date_from']
        date_to=defaults['date_to']
        branch_id=None
        department_id=None
        dom=[]
        if ids:
            obj=self.browse(ids)[0]
            date_from=obj.date_from
            date_to=obj.date_to
            branch_id=obj.branch_id.id
            department_id=obj.department_id.id
        dom.append(['date','>=',date_from])
        dom.append(['date','<=',date_to])
        if branch_id:
            dom.append(['branch_id','=',branch_id])
        if department_id:
            dom.append(['department_id','=',department_id])
        print('dom ', dom)
        hdcases={}
        for hdcase in get_model("clinic.hd.case").search_browse(dom):
            dpt=hdcase.department_id
            if dpt.id not in hdcases.keys():
                hdcases[dpt.id]={
                    'name': dpt.name,
                    'department_id': dpt.id,
                    'branch_id': dpt.branch_id.id,
                    'qty':0,
                }
            hdcases[dpt.id]['qty']+=1
        lines=[] 
        total_hdcase=0
        for dpt_id, vals in hdcases.items():
            qty=vals['qty'] or 0
            total_hdcase+=qty
            lines.append({
                'name': vals['name'],
                'branch_id': vals['branch_id'],
                'department_id': vals['department_id'],
                'qty': qty,
            })
        sub_name=''
        if department_id:
            dpt=get_model("clinic.department").browse(department_id)
            sub_name="(%s)" % dpt.name or ""
        elif branch_id:
            branch=get_model("clinic.branch").browse(branch_id)
            sub_name="(%s)" % branch.name or ""
        
        data={
            'company_name': '%s %s' % (company.name or "", sub_name),
            'date_from': date_from,
            'date_to': date_to,
            'lines': lines,
            'total_hdcase': total_hdcase,
        }
        return data

    def onchange_date(self,context={}):
        data=context['data']
        date=data['date']
        year,month,day=date.split("-")
        weekday, total_day=monthrange(int(year), int(month))
        data['date_from']="%s-%s-01"%(year,month)
        data['date_to']="%s-%s-%s"%(year,month,total_day)
        return data

    def onchange_branch(self,context={}):
        data=context['data']
        data['department_id']=None
        return data

ReportLaborCost.register()
